% Figs_L1.m
% Probability Course - figures for Lec 1.
% pmf, cdf and pdf of 2-dice throws
% pdf and cdf of normal distr.
%
% Nick Kingsbury, Cambridge University, Oct 2002.

% pmf, cdf and pdf of 2-dice throws
thr = [2:12]';
h = [1:6  5:-1:1]';
h = h/sum(h);

pos1 = [0.06 0.3 0.4 0.4]; % Use subplot so text is a reasonable size.

% pmf
setfig(1);
subplot('position',pos1);
bar(thr,h,0.6);
axis([0 14 -0.02 0.2]);
% set(gca,'FontSize',10);
grid on
title('(a) pmf of 2-dice throws','FontSize',12);
xlabel('total throw','FontSize',12);

% cdf
zz = zeros(2,1);
cdf = cumsum([zz; h; zz]);
cdf2 = kron(cdf,[1;1]);
thr2 = [0; kron([1:length(cdf)-1]',[1;1]); length(cdf)];
setfig(2)
subplot('position',pos1);
plot(thr2,cdf2,'LineWidth',2)
axis([0 14 -0.2 1.2])
grid on
title('(b) cdf of 2-dice throws','FontSize',12);
xlabel('total throw','FontSize',12);

n = 20;
pdf = kron([zz; h; zz],[1;zeros(n-1,1)]);
thr3 = ([1:length(pdf)] - 1)/n;

% pdf
setfig(3)
subplot('position',pos1);
plot(thr3,pdf,'LineWidth',2)
axis([0 14 -0.02 0.2]);
grid on
title('(c) pdf of 2-dice throws','FontSize',12);
xlabel('total throw','FontSize',12);

% pdf and cdf of Normal distr with mean 2 and variance 3.
xmean = 2;
sig = sqrt(3);
xmin = -4;
xmax = 8;
dx = 1/64;
x = [xmin:dx:xmax]';
y = exp(-(x-xmean).^2/(2*sig.^2)) / (sqrt(2*pi)*sig);
setfig(4)
subplot('position',pos1);
plot(x,y,'LineWidth',2)
axis([xmin xmax -0.05 0.3]);
grid on
title('(d) pdf of normal distribution: mean = 2, var = 3','FontSize',12);
xlabel('x','FontSize',12);

setfig(5)
subplot('position',pos1);
plot(x,cumsum(y)*dx,'LineWidth',2)
axis([xmin xmax -0.2 1.2]);
grid on
title('(e) cdf of normal distribution: mean = 2, var = 3','FontSize',12);
xlabel('x','FontSize',12);

return

figure(1)
print -depsc '\1ngk\TEX\Probability\Figures\pmf2dice'
figure(2)
print -depsc '\1ngk\TEX\Probability\Figures\cdf2dice'
figure(3)
print -depsc '\1ngk\TEX\Probability\Figures\pdf2dice'
figure(4)
print -depsc '\1ngk\TEX\Probability\Figures\pdfnorm'
figure(5)
print -depsc '\1ngk\TEX\Probability\Figures\cdfnorm'


