% Figs_ensemble.m
% Plot an ensemble of random signals and show the
% difference between wide and narrow band signals
% using ACF and PSD.
%
% Nick Kingsbury, Cambridge University, Oct 2002.

clear all

pos1 = [0.06 0.05 0.9 0.9]; % Use subplot so text is a reasonable size.

if ~exist('d'), rand('state',0); randn('state',0); end


ns = 10;
N = 1000;
h = sin([1:ns-1]'*pi/(ns));
h = h / sqrt(sum(h.*h)); % Unit power gain.

rx = randn(5*N+ns,1);
noise1 = conv(rx,h);

noise = 0.15*reshape(noise1([1:4*N] + ns/2),N,4);

setfig(1)

plot([1:N]',noise - ones(N,1)*[0 1 3 4],'-b','LineWidth',2);
set(gcf,'Color',[1 1 1])
axis off
hold on
plot([N;N]*[0.25 0.75 0.25 0.75],[-1 -1 -4 -4;-2 -2 -5 -5]-0.5,':b','LineWidth',2);
t2 = [0.48 0.52]*N;
plot([1;1]*t2,[1 1;-5 -5],'--r','LineWidth',2);
hold off
t1 = [-10 0];
latext(t1(1),t1(2),'\a_1','r',12);
latext(t1(1),t1(2)-1,'\a_2','r',12);
latext(t1(1),t1(2)-3,'\a_i','r',12);
latext(t1(1),t1(2)-4,'\a_i_+_1','r',12);
latext(t2(1),-5.1,'t_1','t',12);
latext(t2(2),-5.1,'t_2','t',12);
latext(0.9*N,-5.1,'t ->','t',12);
latext(0.27*N,0.5,'X(t,\a_1)','bl',12);
latext(0.27*N,-1.5,'X(t,\a_2)','tl',12);
latext(0.27*N,-2.5,'X(t,\a_i)','bl',12);
latext(0.27*N,-4.5,'X(t,\a_i_+_1)','tl',12);
title('Ensemble of Random Signals','FontSize',12);

ns2 = 50;
h2 = sin([1:ns2-1]'*pi/(ns2));
h2 = h2 / sqrt(sum(h2.*h2)); % Unit power gain.

noise2 = conv(rx,h2);

setfig(2)
subplot('position',[0.1 0.1 0.8 0.6])

t = [1:N]';
plot(t,[noise1(t+ns)  noise2(t+ns2)-6],'-b','LineWidth',2);
% set(gcf,'Color',[1 1 1])
% axis off

Na = 200;
t = [1:4*N]';
acf = zeros(Na,2);
for k=1:Na,
   acf(k,:) = [noise1(t).'*noise1(t+k-1)  noise2(t).'*noise2(t+k)];
end
acf = [acf(end:-1:2,:); acf]/length(t);
S = abs(fft(acf,512));
S(:,1) = fftshift(S(:,1));
S(:,2) = fftshift(S(:,2));

z1 = zeros(Na-length(h),1);
z2 = zeros(Na-length(h2),1);
acfh = [[z1; conv(h,h); z1]  [z2; conv(h2,h2); z2]];  
Sh = abs(fft(acfh,512));
Sh(:,1) = fftshift(Sh(:,1));
Sh(:,2) = fftshift(Sh(:,2));
text(100,3,'Wide bandwidth','FontSize',12);
text(100,-9,'Narrow bandwidth','FontSize',12);
xlabel('time, t (samples)','FontSize',12)
title('(a) Random signals with different bandwidths','FontSize',12);

setfig(3)
subplot('position',[0.1 0.1 0.32 0.6])

plot([1-Na:Na-1]',acf - ones(2*Na-1,1)*[0 1.5],'-r','LineWidth',1);
hold on
plot([1-Na:Na-1]',acfh - ones(2*Na-1,1)*[0 1.5],'-b','LineWidth',2);
hold off
xlabel('time shift, tau (samples)','FontSize',12)
title('(b) ACF of signals','FontSize',12);

subplot('position',[0.58 0.1 0.32 0.6])

plot([-256:255]'/512,S - ones(512,1)*[0 50],'-r','LineWidth',1);
hold on
plot([-256:255]'/512,Sh - ones(512,1)*[0 50],'-b','LineWidth',2);
hold off
axis([-0.2 0.2 -55 15])
xlabel('frequency, f (sample rate)','FontSize',12)
title('(c) PSD of signals','FontSize',12);

return

figure(1)
print -depsc '\1ngk\TEX\Probability\Figures\ensemble'
figure(2)
print -depsc '\1ngk\TEX\Probability\Figures\wide_narrow'
figure(3)
print -depsc '\1ngk\TEX\Probability\Figures\acf_psd'




