% Loaded.m
% Simulation of the loaded dice problem from 3F1 Random Processes lectures.
% This version calculates probabilities one throw at a time.
%
% Nick Kingsbury, Cambridge University, October 2002.

% pmfs for loaded and fair dice.
pl = [0.05 0.15 0.15 0.15 0.15 0.35]'; % loaded
pf = ones(6,1)/6; % fair

ndice = 100; % Total no of dice in tub.
p1 = 1e-4, p2 = 0.995
% p1 = 1e-5, p2 = 0.9995

% Ensure pmfs sum to unity.
pl = pl/sum(pl);
pf = pf/sum(pf);

state = zeros(ndice,1);
state(20) = 1; % Should really be random, but choose an early position to keep the test short.
i = 0; % Die counter.
found = 0; % becomes 1 when loaded die is found.
Pl = 1/ndice;
Rr = ndice-1;
H = zeros(6,1);
if ~exist('r'), rand('state',0); end
Ntot = 0; % Total number of throws. 

% Loop for each die picked from the tub.
while (found == 0) & (i < ndice),
   i = i + 1;
   % Set correct pmf for the current die.
   if state(i), pmf = pl;
   else pmf = pf;
   end
   cdf = [0; cumsum(pmf)]; % Calculate current cdf.
   throw = 0; % Set throw to zero.
   h = zeros(6,1); % Set histogram to zero.
   N = 0;
   
   R = ndice - 1; % Prior on ratio of prob of fair to prob of loaded.
   ploaded = 1/(R + 1);
   
   % Loop for each batch of n throws
   while (ploaded > p1) & (found == 0),
      % Perform n throws and update list of throws.
      r = rand(1,1);
      % Determine which throw(s) was made.
      for k = 1:6,
          if (r >= cdf(k)) & (r < cdf(k+1)),
              throw = k;
              h(k) = h(k) + 1;
          end
      end
      N = N + 1;
      
      % Compute cumulative ratio of probabilities for loaded and fair.
      R = R * pf(throw) / pl(throw); % Divide terms before taking product to avoid underflow.
      
      ploaded = 1 / (1+R);
      Rr = [Rr R];
      Pl = [Pl  ploaded];
      H = [H  h];
      found = (ploaded > p2);
      Ntot = length(Pl) - 1;
      
      if (i == 1) | (ploaded <= p1), 
          setfig(1); 
          semilogy(0:Ntot,Pl,'LineWidth',2); 
          axis([0 ceil(Ntot/100)*100 1e-5 1]);
          grid on
          hold on
          semilogy([0 Ntot],[p1 p1],'r','LineWidth',2);
          text(Ntot,p1*1.1,'p1','FontSize',14,'vert','bot','horiz','cen','color','red');
          hold off
          title(sprintf('Throw = %d    Probability of die(%d) being ''loaded''',throw,i),'FontSize',14);
          xlabel('no. of throws','FontSize',14);
          pause; 
      end
  end
  disp(sprintf('i = %2d, N = %d, P_loaded = %.6f, h: %4d %4d %4d %4d %4d %4d', i, N, ploaded, h));
end
Ntot

setfig(1); 
semilogy(Pl,'LineWidth',2); 
grid on
hold on
semilogy([1 Ntot],[p1 p1],'r','LineWidth',2);
text(Ntot,p1*1.1,'p1','FontSize',14,'vert','bot','horiz','cen','color','red');
hold off
          title(sprintf('Probability of dice(1:%d) being ''loaded''',i),'FontSize',14);
xlabel('no. of throws','FontSize',14);

setfig(2); 
surf(1:size(H,2),floor([1:12]/2),kron(H,ones(2,1))); shading flat
colormap(hot);
title('Surface plot of histograms of throws','FontSize',14);
xlabel('no. of throws','FontSize',14);
ylabel('value of throw','FontSize',14);

setfig(3); 
subplot('position',[0.06 0.3 0.9 0.3]);
imagesc(H); 
colormap(hot); 
axis xy
title('Image plot of histograms of throws','FontSize',14);
xlabel('no. of throws','FontSize',14);
ylabel('value of throw','FontSize',14);

figure(1)
return

figure(1)
print -depsc '\1ngk\TEX\Probability\Figures\loaded_probs'

figure(2)
print -depsc '\1ngk\TEX\Probability\Figures\loaded_surf'

figure(3)
colormap(gray); 
print -depsc '\1ngk\TEX\Probability\Figures\loaded_image'
colormap(hot); 

